dispose method
Disposes of the plug.
This method should be overridden to perform any necessary cleanup when the plug is being removed. The default implementation returns the plug instance itself.
Implementation
Future<Plug> dispose() async => this;
Disposes of the plug.
This method should be overridden to perform any necessary cleanup when the plug is being removed. The default implementation returns the plug instance itself.
Future<Plug> dispose() async => this;