map method
Throws an exception if called, as this is an async mapper
Implementation
@override
TO map(FROM source) {
throw Exception('Called map() on an AsyncMapper');
}
Throws an exception if called, as this is an async mapper
@override
TO map(FROM source) {
throw Exception('Called map() on an AsyncMapper');
}