DartFrogServerPlug class
Constructors
- DartFrogServerPlug({required Handler rootHandler, required InternetAddress internetAddress, required int port})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ip → InternetAddress
-
The IP address the server will listen on.
finalinherited
- port → int
-
The port number the server will listen on.
finalinherited
- rootHandler → Handler
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< Plug< Plug> > -
Disposes of the plug.
inherited
-
handle<
REQUEST, RES> ({required REQUEST request, required RequestHandler handler}) → Future< RES> - Handles an HTTP request using the provided handler.
-
init(
) → Future< DartFrogServerPlug> - Initializes the plug.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
{required InternetAddress ip, required int port, List< String> mounts = const ['/'], String? poweredByHeader = 'Dart Pluggable', SecurityContext? securityContext, }) → Future<HttpServer> - Runs the HTTP server with the specified configuration.
-
sameType<
X extends Plug< (X> >) → bool -
Checks if this plug is of the same type as another plug.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited